#
# spec file for package liblangtag
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define libname liblangtag1
Name:           liblangtag
Version:        0.6.2
Release:        150000.3.6.1
Summary:        An interface library to access tags for identifying languages
License:        LGPL-3.0-or-later OR MPL-2.0
Group:          Productivity/Publishing/Word
URL:            https://bitbucket.org/tagoh/liblangtag
Source0:        https://bitbucket.org/tagoh/%{name}/downloads/%{name}-%{version}.tar.bz2
BuildRequires:  gcc-c++
BuildRequires:  gettext
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(check)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gtk-doc)
BuildRequires:  pkgconfig(libxml-2.0)

%description
%{name} is an interface library to access tags for identifying
languages.

Features:
* several subtag registry database supports:
  - language
  - extlang
  - script
  - region
  - variant
  - extension
  - grandfathered
  - redundant
* handling of the language tags
  - parser
  - matching
  - canonicalizing

%package -n %{libname}
Summary:        C++ library for identification of the language from tags
Group:          System/Libraries

%description -n %{libname}
%{name} is an interface library to access tags for identifying
languages.

Features:
* several subtag registry database supports:
  - language
  - extlang
  - script
  - region
  - variant
  - extension
  - grandfathered
  - redundant
* handling of the language tags
  - parser
  - matching
  - canonicalizing

%package devel
Summary:        Files for Developing with %{name}
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}
Requires:       pkgconfig(glib-2.0)

%description devel
%{name} is an interface library to access tags for identifying
languages.

This package contains the %{name} development files.

%package doc
Summary:        Documentation of %{name} API
Group:          Documentation/HTML
BuildArch:      noarch

%description doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%setup -q

%build
%configure \
	--disable-silent-rules \
	--disable-static \
	--enable-test \
	--disable-introspection \
	--docdir=%{_docdir}/%{name}
# tests/check-*.c: warning: too many arguments for format [-Wformat-extra-args]
# in fail_unless()
sed -i 's:^\(CFLAGS =.*\):\1 -Wno-error=format-extra-args:' tests/Makefile
make %{?_smp_mflags}

%install
%make_install

find %{buildroot} -type f -name "*.la" -delete -print

%check
make %{?_smp_mflags} check

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%license COPYING
%dir %{_libdir}/%{name}/
%dir %{_datadir}/%{name}/
%{_libdir}/*.so.1*
%{_libdir}/%{name}/*
%{_datadir}/%{name}/*

%files devel
%{_libdir}/*.so
%{_libdir}/pkgconfig/%{name}*.pc
%{_includedir}/%{name}*

%files doc
%dir %{_datadir}/gtk-doc/html/
%{_datadir}/gtk-doc/html/%{name}

%changelog
* Tue Apr  5 2022 pgajdos@suse.com
- allow to build for later service packs of SLE 15 [bsc#1197767]
  (-Wno-error=format-extra-args)
* Wed May 30 2018 tchvatal@suse.com
- Version update to 0.6.2:
  * use standard function
  * fix leak in test
* Mon Sep 26 2016 tchvatal@suse.com
- Version update to 0.6.1:
  * Initialize databases just once.
  * Support BCP47-like locale representation
  * Use deprecation macros
  * Add a lookup table to catch up a script/language from language/script
  * Update to add more files into .gitignore
  * Fix the behavior on lt_tag_transform() according to tr#35
  * Fix a segfault if no territory or script is given to lt_tag_convert_from_locale_string()
  * Add missing header file
  * Add lt_db_set_val() to change the place of database
  * Fix memory leaks
  * missing gobject function for lt_relation_db thing
  * Support the language alias for the canonicalization
  * Fix lt_trie_keys() not working
  * Fix OOM handling
  * Improve the bootup time
  * Add docs
  * Update the library versioning
* Mon Dec 21 2015 tchvatal@suse.com
- Version bump to 0.5.8:
  * Fix the build requirement in pkgconfig file
  * Make some header files public (fixes: issue#14)
  * Fix test fail on SunOS
  * Fix unknown node issue
* Tue Jul 14 2015 tchvatal@suse.com
- Version bump to 0.5.7:
  * Tons of fixes between 0.5.4 and this release. Read NEWS file
* Wed Jun 25 2014 tchvatal@suse.com
- Version bump to 0.5.4:
  * Various small items detailed in NEWS file
  * Removed language stubtag registry
* Tue May 20 2014 tchvatal@suse.com
- Add condition around noarch doc subpkg to work with SLE11
* Mon May 12 2014 tchvatal@suse.com
- Version bump to 0.5.3:
  * Various small fixes detailed in NEWS file
* Mon Sep 23 2013 tchvatal@suse.com
- Version bump to 0.5.2
  * Various autootool fixes
  * coverity fixes
  * For more read up NEWS file
* Wed May  1 2013 tchvatal@suse.com
- Version bump to 0.5.1
  * resolves abi compatibility issues.
* Sat Apr 27 2013 tchvatal@suse.com
- Version bump to 0.5
  * Enhancements:
  * Iterator support
  * Add lt_tag_convert_from_locale_string()
  * Bug Fixes:
  * Fix wrong traversal on keys
  * Fix xml parser for tags in range
  * Improve portability
  * Fix broken lt_tag_transform()
  * Fix the build issue when builddir != srcdir
  * Fix broken lt_tag_convert_from_locale()
  * Fix memory leaks
  * Fix linker issue
  * Use secure_getenv if available
  * more
- Remove upstreamed patches.
* Sat Apr 20 2013 tchvatal@suse.com
- Use full download url.
- Apply patches from git to fix few build issues.
* Wed Nov 14 2012 tchvatal@suse.com
- Fix Requires to demand glib2-devel not gtk1 variant
  (thanks coolo)
  * Fix copy&pasto in one summary.
* Tue Nov 13 2012 tchvatal@suse.com
- Use both lpgl and mpl licenses.
  * thanks to babelworx for the hint (merge request fails to
    complete so doing it myself).
* Fri Nov  9 2012 tchvatal@suse.com
- Fix desc not to contain mention of libexttextcat.
* Wed Nov  7 2012 tchvatal@suse.com
- Add missing directory to the list.
* Tue Nov  6 2012 tchvatal@suse.com
- Initial package. Version 0.4.0.
